"use strict";
(() => {
  var __create = Object.create;
  var __defProp = Object.defineProperty;
  var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
  var __getOwnPropNames = Object.getOwnPropertyNames;
  var __getProtoOf = Object.getPrototypeOf;
  var __hasOwnProp = Object.prototype.hasOwnProperty;
  var __require = /* @__PURE__ */ ((x) => typeof require !== "undefined" ? require : typeof Proxy !== "undefined" ? new Proxy(x, {
    get: (a, b) => (typeof require !== "undefined" ? require : a)[b]
  }) : x)(function(x) {
    if (typeof require !== "undefined")
      return require.apply(this, arguments);
    throw Error('Dynamic require of "' + x + '" is not supported');
  });
  var __copyProps = (to, from, except, desc) => {
    if (from && typeof from === "object" || typeof from === "function") {
      for (let key of __getOwnPropNames(from))
        if (!__hasOwnProp.call(to, key) && key !== except)
          __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
    }
    return to;
  };
  var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
    // If the importer is in node compatibility mode or this is not an ESM
    // file that has been converted to a CommonJS file using a Babel-
    // compatible transform (i.e. "__esModule" has not been set), then set
    // "default" to the CommonJS "module.exports" for node compatibility.
    isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
    mod
  ));

  // src/index.ts
  var import_promises = __require("fs/promises");
  var path = __toESM(__require("path"));
  var url = __toESM(__require("url"));
  var VALID_HTTP_METHODS = ["GET", "PUT", "POST", "DELETE", "PATCH", "HEAD", "OPTIONS"];
  async function setupFileRouter(router, options) {
    if (!router) {
      throw new Error("Router must be set up.");
    }
    const routerDirectory = path.normalize(options?.directory ?? "routes");
    const files = await getFiles(routerDirectory);
    console.log(`[File Router] Using "${routerDirectory}" as route directory.`);
    for (const file of files) {
      const { href: handlerPath } = url.pathToFileURL(path.join(file));
      const handler = await import(handlerPath);
      const cleanedDirectory = path.parse(file).dir.replace(routerDirectory, "").replaceAll("\\", "/");
      const routeDirectory = cleanedDirectory.trim() === "" ? "/" : cleanedDirectory;
      const methods = Object.keys(handler).filter((handlerMethod) => VALID_HTTP_METHODS.includes(handlerMethod));
      methods.forEach((method) => {
        createRoute(router, routeDirectory, method, handler[method]);
      });
    }
  }
  async function getFiles(dir, extensions = ["ts", "js"]) {
    const files = await (0, import_promises.readdir)(dir, { withFileTypes: true });
    const filePaths = [];
    for (let file of files) {
      if (file.isDirectory()) {
        const subDirFiles = await getFiles(path.join(dir, file.name), extensions);
        filePaths.push(...subDirFiles);
      } else if (extensions.some((ext) => file.name.endsWith(`.${ext}`))) {
        filePaths.push(path.join(dir, file.name));
      }
    }
    return filePaths;
  }
  function createRoute(router, route, method, handler) {
    route = route.split("/").map((part) => part.replace(/\[([^\]]+)\]/g, ":$1")).join("/");
    router[method.toLowerCase()]?.(route, handler);
    console.log(`[File Router] Created route ${route} with ${method.toUpperCase()} method.`);
  }
})();
