"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  setupFileRouter: () => setupFileRouter
});
module.exports = __toCommonJS(src_exports);
var import_promises = require("fs/promises");
var path = __toESM(require("path"));
var url = __toESM(require("url"));
var VALID_HTTP_METHODS = ["GET", "PUT", "POST", "DELETE", "PATCH", "HEAD", "OPTIONS"];
async function setupFileRouter(router, options) {
  if (!router) {
    throw new Error("Router must be set up.");
  }
  const routerDirectory = path.normalize(options?.directory ?? "routes");
  const files = await getFiles(routerDirectory);
  console.log(`[File Router] Using "${routerDirectory}" as route directory.`);
  for (const file of files) {
    const { href: handlerPath } = url.pathToFileURL(path.join(file));
    const handler = await import(handlerPath);
    const cleanedDirectory = path.parse(file).dir.replace(routerDirectory, "").replaceAll("\\", "/");
    const routeDirectory = cleanedDirectory.trim() === "" ? "/" : cleanedDirectory;
    const methods = Object.keys(handler).filter((handlerMethod) => VALID_HTTP_METHODS.includes(handlerMethod));
    methods.forEach((method) => {
      createRoute(router, routeDirectory, method, handler[method]);
    });
  }
}
async function getFiles(dir, extensions = ["ts", "js"]) {
  const files = await (0, import_promises.readdir)(dir, { withFileTypes: true });
  const filePaths = [];
  for (let file of files) {
    if (file.isDirectory()) {
      const subDirFiles = await getFiles(path.join(dir, file.name), extensions);
      filePaths.push(...subDirFiles);
    } else if (extensions.some((ext) => file.name.endsWith(`.${ext}`))) {
      filePaths.push(path.join(dir, file.name));
    }
  }
  return filePaths;
}
function createRoute(router, route, method, handler) {
  route = route.split("/").map((part) => part.replace(/\[([^\]]+)\]/g, ":$1")).join("/");
  router[method.toLowerCase()]?.(route, handler);
  console.log(`[File Router] Created route ${route} with ${method.toUpperCase()} method.`);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  setupFileRouter
});
