// src/index.ts
import { readdir } from "fs/promises";
import * as path from "path";
import * as url from "url";
var VALID_HTTP_METHODS = ["GET", "PUT", "POST", "DELETE", "PATCH", "HEAD", "OPTIONS"];
async function setupFileRouter(router, options) {
  if (!router) {
    throw new Error("Router must be set up.");
  }
  const routerDirectory = path.normalize(options?.directory ?? "routes");
  const files = await getFiles(routerDirectory);
  console.log(`[File Router] Using "${routerDirectory}" as route directory.`);
  for (const file of files) {
    const { href: handlerPath } = url.pathToFileURL(path.join(file));
    const handler = await import(handlerPath);
    const cleanedDirectory = path.parse(file).dir.replace(routerDirectory, "").replaceAll("\\", "/");
    const routeDirectory = cleanedDirectory.trim() === "" ? "/" : cleanedDirectory;
    const methods = Object.keys(handler).filter((handlerMethod) => VALID_HTTP_METHODS.includes(handlerMethod));
    methods.forEach((method) => {
      createRoute(router, routeDirectory, method, handler[method]);
    });
  }
}
async function getFiles(dir, extensions = ["ts", "js"]) {
  const files = await readdir(dir, { withFileTypes: true });
  const filePaths = [];
  for (let file of files) {
    if (file.isDirectory()) {
      const subDirFiles = await getFiles(path.join(dir, file.name), extensions);
      filePaths.push(...subDirFiles);
    } else if (extensions.some((ext) => file.name.endsWith(`.${ext}`))) {
      filePaths.push(path.join(dir, file.name));
    }
  }
  return filePaths;
}
function createRoute(router, route, method, handler) {
  route = route.split("/").map((part) => part.replace(/\[([^\]]+)\]/g, ":$1")).join("/");
  router[method.toLowerCase()]?.(route, handler);
  console.log(`[File Router] Created route ${route} with ${method.toUpperCase()} method.`);
}
export {
  setupFileRouter
};
